@@ -10,7 +10,6 @@ from time import strftime
 class Exec:
     case_idx = 1
     def __init__(self,data):
-        global case_idx
         self.data = data
         if 'browser' in self.data[0]:
             if self.data[0]['browser'] == 'chrome':
@@ -32,7 +31,7 @@ class Exec:
                 with allure.step(f'步骤{step}:{step_text}'):
                     self.driver.get(goto_data)
                     log.info(f'步骤{step}:{step_text}')
-                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{Exec.case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name,'rb') as f:
                         file = f.read()
@@ -53,7 +52,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={input_ele[:-1][0]},定位的值{input_ele[:-1][-1]}')
                     log.info(f'输入的值{input_ele[-1]}')
-                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{Exec.case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -71,7 +70,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={click_data[0]},定位的值{click_data[-1]}')
                     log.info('点击元素')
-                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{Exec.case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -104,7 +103,7 @@ class Exec:
                         except Exception as error:
                             log.info(f'步骤{step}:{step_text}')
                             log.error(f'断言失败，期望值{assert_data[0]},实际值{result}')
-                            file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}断言失败.png'
+                            file_name = f'screenshot/case{Exec.case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}断言失败.png'
                             self.driver.save_screenshot(file_name)
                             with open(file_name, 'rb') as f:
                                 file = f.read()
@@ -127,7 +126,7 @@ class Exec:
                     var = text_ele[-1]
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'保存变量{var},变量值为{text_msg}')
-                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{Exec.case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -145,7 +144,7 @@ class Exec:
                     var = text_ele[-1]
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'保存变量{var},变量值为{text_msg}')
-                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{Exec.case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
